@@ -39,7 +39,7 @@ from oslo_concurrency._i18n import _
 
 if os.name == 'nt':
     warnings.warn('Support for Windows OS is deprecated.',
-                  category=DeprecationWarning, stacklevel=3)
+                  category=DeprecationWarning)
 
 
 # NOTE(bnemec): eventlet doesn't monkey patch subprocess, so we need to
@@ -61,13 +61,6 @@ if eventlet_patched:
         from eventlet.green import subprocess
 
     from eventlet import tpool
-
-    # Monkey patch the original current_thread to use the up-to-date _active
-    # global variable. See https://bugs.launchpad.net/bugs/1863021 and
-    # https://github.com/eventlet/eventlet/issues/592
-    import __original_module_threading as orig_threading
-    import threading
-    orig_threading.current_thread.__globals__['_active'] = threading._active
 else:
     import subprocess
 
@@ -77,18 +70,18 @@ LOG = logging.getLogger(__name__)
 
 class InvalidArgumentError(Exception):
     def __init__(self, message=None):
-        super(InvalidArgumentError, self).__init__(message)
+        super().__init__(message)
 
 
 class UnknownArgumentError(Exception):
     def __init__(self, message=None):
-        super(UnknownArgumentError, self).__init__(message)
+        super().__init__(message)
 
 
 class ProcessExecutionError(Exception):
     def __init__(self, stdout=None, stderr=None, exit_code=None, cmd=None,
                  description=None):
-        super(ProcessExecutionError, self).__init__(
+        super().__init__(
             stdout, stderr, exit_code, cmd, description)
         self.exit_code = exit_code
         self.stderr = stderr
@@ -119,7 +112,7 @@ class ProcessExecutionError(Exception):
 
 class NoRootWrapSpecified(Exception):
     def __init__(self, message=None):
-        super(NoRootWrapSpecified, self).__init__(message)
+        super().__init__(message)
 
 
 def _subprocess_setup(on_preexec_fn):
@@ -153,7 +146,7 @@ LOG_FINAL_ERROR = LogErrors.FINAL
 LOG_DEFAULT_ERROR = LogErrors.DEFAULT
 
 
-class ProcessLimits(object):
+class ProcessLimits:
     """Resource limits on a process.
 
     Attributes:
@@ -199,7 +192,7 @@ class ProcessLimits(object):
         for limit in self._LIMITS:
             val = getattr(self, limit)
             if val is not None:
-                args.append("%s=%s" % (self._LIMITS[limit], val))
+                args.append("{}={}".format(self._LIMITS[limit], val))
         return args
 
 
